==> rendition-11.10.0.tgz: package/dist_esm5/components/DataTypes/string.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Input from '../Input';
import Textarea from '../Textarea';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    contains: {
        getLabel: function (_s) { return 'contains'; },
    },
    not_contains: {
        getLabel: function (_s) { return 'does not contain'; },
    },
    matches_re: {
        getLabel: function (_s) { return 'matches RegEx'; },
    },
    not_matches_re: {
        getLabel: function (_s) { return 'does not match RegEx'; },
    },
};
export var decodeFilter = function (filter) {
    var operator = filter.title;
    var value;
    var field;
    if (filter.properties) {
        var keys = Object.keys(filter.properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'is') {
            value = filter.properties[field].const;
        }
        else if (operator === 'contains') {
            value = filter.properties[field].description;
        }
        else if (operator === 'matches_re') {
            value = filter.properties[field].pattern;
        }
        else {
            return null;
        }
    }
    else if (filter.anyOf) {
        if (filter.anyOf.length === 0 || !filter.anyOf[0].properties) {
            return null;
        }
        var keys = Object.keys(filter.anyOf[0].properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'not_contains') {
            value = filter.anyOf[0].properties[field].description;
        }
        else if (operator === 'not_matches_re') {
            value = filter.anyOf[0].properties[field].not.pattern;
        }
        else {
            return null;
        }
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c, _d, _e, _f, _g;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: (title || field) + " " + operators[operator].getLabel(schema) + " " + value,
        type: 'object',
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    title: title,
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'contains') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'string',
                    description: value,
                    pattern: utils.regexEscape(value),
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'not_contains') {
        return assign(base, {
            anyOf: [
                {
                    properties: (_c = {},
                        _c[field] = {
                            type: 'string',
                            description: value,
                            not: {
                                pattern: utils.regexEscape(value),
                            },
                        },
                        _c),
                },
                {
                    properties: (_d = {},
                        _d[field] = {
                            type: 'null',
                        },
                        _d),
                },
            ],
        });
    }
    if (operator === 'matches_re') {
        return assign(base, {
            properties: (_e = {},
                _e[field] = {
                    type: 'string',
                    pattern: value,
                },
                _e),
            required: [field],
        });
    }
    if (operator === 'not_matches_re') {
        return assign(base, {
            anyOf: [
                {
                    properties: (_f = {},
                        _f[field] = {
                            type: 'string',
                            not: {
                                pattern: value,
                            },
                        },
                        _f),
                },
                {
                    properties: (_g = {},
                        _g[field] = {
                            type: 'null',
                        },
                        _g),
                },
            ],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var onUpdate = _a.onUpdate, slim = _a.slim, props = tslib_1.__rest(_a, ["onUpdate", "slim"]);
    if (slim) {
        return (React.createElement(Input, tslib_1.__assign({ onChange: function (e) {
                return onUpdate(e.currentTarget.value);
            } }, props)));
    }
    return (React.createElement(Textarea, tslib_1.__assign({ onChange: function (e) {
            return onUpdate(e.currentTarget.value);
        } }, props)));
};

==> rendition-11.21.1.tgz: package/dist_esm5/components/DataTypes/string.js <==
import { __assign, __rest } from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Input from '../Input';
import Textarea from '../Textarea';
import { getJsonDescription } from './utils';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    contains: {
        getLabel: function (_s) { return 'contains'; },
    },
    not_contains: {
        getLabel: function (_s) { return 'does not contain'; },
    },
    matches_re: {
        getLabel: function (_s) { return 'matches RegEx'; },
    },
    not_matches_re: {
        getLabel: function (_s) { return 'does not match RegEx'; },
    },
};
export var decodeFilter = function (filter) {
    var operator = filter.title;
    var value;
    var field;
    if (filter.properties) {
        var keys = Object.keys(filter.properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'is') {
            value = filter.properties[field].const;
        }
        else if (operator === 'contains') {
            value = filter.properties[field].description;
        }
        else if (operator === 'matches_re') {
            value = filter.properties[field].pattern;
        }
        else {
            return null;
        }
    }
    else if (filter.anyOf) {
        if (filter.anyOf.length === 0 || !filter.anyOf[0].properties) {
            return null;
        }
        var keys = Object.keys(filter.anyOf[0].properties);
        if (!keys.length) {
            return null;
        }
        field = keys[0];
        if (operator === 'not_contains') {
            value = filter.anyOf[0].properties[field].description;
        }
        else if (operator === 'not_matches_re') {
            value = filter.anyOf[0].properties[field].not.pattern;
        }
        else {
            return null;
        }
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c, _d, _e, _f, _g;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: getJsonDescription(title || field, operators[operator].getLabel(schema), value),
        type: 'object',
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    title: title,
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'contains') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'string',
                    description: value,
                    pattern: utils.regexEscape(value),
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'not_contains') {
        return assign(base, {
            anyOf: [
                {
                    properties: (_c = {},
                        _c[field] = {
                            type: 'string',
                            description: value,
                            not: {
                                pattern: utils.regexEscape(value),
                            },
                        },
                        _c),
                },
                {
                    properties: (_d = {},
                        _d[field] = {
                            type: 'null',
                        },
                        _d),
                },
            ],
        });
    }
    if (operator === 'matches_re') {
        return assign(base, {
            properties: (_e = {},
                _e[field] = {
                    type: 'string',
                    pattern: value,
                },
                _e),
            required: [field],
        });
    }
    if (operator === 'not_matches_re') {
        return assign(base, {
            anyOf: [
                {
                    properties: (_f = {},
                        _f[field] = {
                            type: 'string',
                            not: {
                                pattern: value,
                            },
                        },
                        _f),
                },
                {
                    properties: (_g = {},
                        _g[field] = {
                            type: 'null',
                        },
                        _g),
                },
            ],
        });
    }
    return base;
};
export var Edit = function (_a) {
    var onUpdate = _a.onUpdate, slim = _a.slim, props = __rest(_a, ["onUpdate", "slim"]);
    if (slim) {
        return (React.createElement(Input, __assign({ onChange: function (e) {
                return onUpdate(e.currentTarget.value);
            } }, props)));
    }
    return (React.createElement(Textarea, __assign({ onChange: function (e) {
            return onUpdate(e.currentTarget.value);
        } }, props)));
};
